about summary refs log tree commit diff
path: root/compiler/rustc_codegen_llvm/src/debuginfo
diff options
context:
space:
mode:
authorGus Caplan <me@gus.host>2020-12-30 12:52:21 -0600
committerGus Caplan <me@gus.host>2021-04-04 11:29:34 -0500
commitda66a31572e0f49981d6b958ecdd95397ecf2d3f (patch)
tree55b595fb8db8356d328dd83999db2dea646829cc /compiler/rustc_codegen_llvm/src/debuginfo
parent5d04957a4b4714f71d38326fc96a0b0ef6dc5800 (diff)
downloadrust-da66a31572e0f49981d6b958ecdd95397ecf2d3f.tar.gz
rust-da66a31572e0f49981d6b958ecdd95397ecf2d3f.zip
wasm64
Diffstat (limited to 'compiler/rustc_codegen_llvm/src/debuginfo')
-rw-r--r--compiler/rustc_codegen_llvm/src/debuginfo/metadata.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/rustc_codegen_llvm/src/debuginfo/metadata.rs b/compiler/rustc_codegen_llvm/src/debuginfo/metadata.rs
index d5b32e58cc3..a6a7f6e0f5b 100644
--- a/compiler/rustc_codegen_llvm/src/debuginfo/metadata.rs
+++ b/compiler/rustc_codegen_llvm/src/debuginfo/metadata.rs
@@ -1083,9 +1083,9 @@ pub fn compile_unit_metadata(
             );
         }
 
         // Insert `llvm.ident` metadata on the wasm32 targets since that will
         // get hooked up to the "producer" sections `processed-by` information.
-        if tcx.sess.opts.target_triple.triple().starts_with("wasm32") {
+        if tcx.sess.target.is_like_wasm {
             let name_metadata = llvm::LLVMMDStringInContext(
                 debug_context.llcontext,
                 rustc_producer.as_ptr().cast(),
@@ -1083,9 +1083,9 @@ pub fn compile_unit_metadata(
         }
 
-        // Insert `llvm.ident` metadata on the wasm32 targets since that will
+        // Insert `llvm.ident` metadata on the wasm targets since that will
         // get hooked up to the "producer" sections `processed-by` information.